/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.modelsconference.ui.generator;

import static org.fortiss.af3.project.ui.AF3ProjectUIActivator.getImageDescriptor;

import org.eclipse.jface.resource.ImageDescriptor;
import org.fortiss.af3.deployment.model.Deployment;
import org.fortiss.af3.project.extension.IExecutionTarget;
import org.fortiss.af3.project.services.IExecutionService;
import org.fortiss.af3.project.ui.execution.EasyStartMenuBase;
import org.fortiss.tooling.kernel.model.INamedElement;
import org.fortiss.tooling.kernel.ui.extension.data.ContextMenuContextProvider;
import org.fortiss.tooling.kernel.ui.service.IContextMenuService;
import org.fortiss.tooling.kernel.ui.service.INavigatorService;

/**
 * {@link EasyStartMenuBase} for the {@link SSHDeploymentGeneratorExecutionTarget}.
 * 
 * @author hoelzl
 * @author bayha
 */
public class SSHDeploymentGeneratorEasyStartMenu extends EasyStartMenuBase {

	/** Constructor. */
	public SSHDeploymentGeneratorEasyStartMenu() {
		super(getDeploymentGeneratorTargetFromExecutionService());
	}

	/** Returns the simulator execution target. */
	private static IExecutionTarget getDeploymentGeneratorTargetFromExecutionService() {
		return IExecutionService.INSTANCE
				.getSpecificExecutionTarget(SSHDeploymentGeneratorExecutionTarget.class);
	}

	/** {@inheritDoc} */
	@Override
	public String getMenuSectionID() {
		return IContextMenuService.BOTTOM_MOST_MENU_SECTION_ID;
	}

	/** {@inheritDoc} */
	@Override
	protected boolean acceptSelection(INamedElement selection,
			ContextMenuContextProvider contextProvider) {
		return (selection instanceof Deployment) &&
				INavigatorService.getInstance().isNavigatorView(contextProvider);
	}

	/** {@inheritDoc} */
	@Override
	protected String getActionName() {
		return "Run DeploymentGenerator and deploy";
	}

	/** {@inheritDoc} */
	@Override
	protected ImageDescriptor getActionIcon() {
		return getImageDescriptor("icons/execution_configuration.gif");
	}

	/** {@inheritDoc} */
	@Override
	protected String getStartupFailureMessage(Exception e) {
		return "Starting the code generator failed. Please check if your model is free of error markers and every component has a defined behavior. Please consult the error log for detailed error information.";
	}
}
